-------------------------------------------------------------------------------
-- | Constructive Algebra Library 
-- 
-- Anders Mortberg    <mortberg@student.chalmers.se>
-- Bassel Mannaa      <mannaa@student.chalmers.se>
--
-- Abstract:
-- This is a library written as part of our master theses. It focuses mainly
-- on the theory of commutative rings from a constructive point of view. 
--
-------------------------------------------------------------------------------

module README where


--------------------------------------------------------------------------------
-- Structures

-- Rings with basic operations. 
import Algebra.Structures.Ring

-- Commutative rings.
import Algebra.Structures.CommutativeRing

-- Integral domains.
import Algebra.Structures.IntegralDomain

-- Fields.
import Algebra.Structures.Field

-- Strongly discrete rings - Rings with decidable ideal membership.
import Algebra.Structures.StronglyDiscrete

-- EuclideanDomains - Integral domains with decidable division and and Euclidean
-- function. Contains lots of functions that are possible at the level of 
-- Euclidean domain like the Euclidean algorithm and extended Euclidean 
-- algorithm.
import Algebra.Structures.EuclideanDomain

-- Bezout domains - Non-Noetherian analogues of principal ideal domains. All 
-- finitely generated ideals are principal.
import Algebra.Structures.BezoutDomain

-- GCD domains - Non-Noetherian analogues of unique factorization domains. 
-- All pairs of nonzero elements have a greatest common divisor.
import Algebra.Structures.GCDDomain

-- Field of fractions of a GCD domain.
import Algebra.Structures.FieldOfFractions


-------------------------------------------------------------------------------
-- Special constructions.

-- Finitely generated ideals over commutative rings. 
import Algebra.Ideal


-------------------------------------------------------------------------------
-- Instances.

-- The integers.
import Algebra.Z

-- The rational numbers as the field of fractions of Z. 
import Algebra.Q


-------------------------------------------------------------------------------
-- The end.
